@@ -1,5 +1,5 @@
 /* Webcamoid, webcam capture application.
- * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
+ * Copyright (C) 2016  Gonzalo Exequiel Pedone
  *
  * Webcamoid is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,13 +24,12 @@ QObject *AudioDevice::create(const QString &key, const QString &specification)
 {
     Q_UNUSED(specification)
 
-    if (key == AK_PLUGIN_TYPE_ELEMENT)
-        return new AudioDeviceElement();
-
-    return nullptr;
+    return new AudioDeviceElement();
 }
 
 QStringList AudioDevice::keys() const
 {
-    return QStringList();
+    return {};
 }
+
+#include "moc_audiodevice.cpp"
